@@ -1,4 +1,4 @@
-# Copyright 2014-2018, Paul Johnson (paul@pjcj.net)
+# Copyright 2014-2019, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Collection;
 use 5.26.0;
 use warnings;
 
-our $VERSION = '1.31'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 use Devel::Cover::DB;
 use Devel::Cover::DB::IO::JSON;
@@ -594,12 +594,12 @@ sub get_latest {
 
     while (my $release = $iterator->next_release) {
         say $release->path;
-        next;
-        printf "%s path=%s  time=%d  size=%d\n",
-               $release->distname,
-               $release->path,
-               $release->timestamp,
-               $release->size;
+        # Debugging code:
+        # printf "%s path=%s  time=%d  size=%d\n",
+               # $release->distname,
+               # $release->path,
+               # $release->timestamp,
+               # $release->size;
     }
 }
 
@@ -703,7 +703,7 @@ package Devel::Cover::Collection::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.31'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
 use base "Template::Provider";
 
@@ -740,7 +740,7 @@ $Templates{html} = <<'EOT';
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
 This file was generated by Devel::Cover Version $VERSION
-Devel::Cover is copyright 2001-2018, Paul Johnson (paul\@pjcj.net)
+Devel::Cover is copyright 2001-2019, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -884,7 +884,7 @@ Devel::Cover::Collection - Code coverage for a collection of modules
 
 =head1 VERSION
 
-version 1.31
+version 1.33
 
 =head1 SYNOPSIS
 
@@ -900,7 +900,7 @@ Almost certainly.
 
 =head1 LICENCE
 
-Copyright 2014-2018, Paul Johnson (paul@pjcj.net)
+Copyright 2014-2019, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
