@@ -10,13 +10,12 @@
 package  # Private module
    Devel::Cover::Dumper;
 
-use strict qw<vars subs>; # no refs
+use strict qw( vars subs );  # no refs
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.33'; # VERSION
 
-sub import
-{
+sub import {
     my $caller = caller;
     if (defined &{"${caller}::Dumper"} && \&{"${caller}::Dumper"} != \&Dumper) {
         require Carp;
@@ -26,10 +25,9 @@ sub import
     *{"${caller}::Dumper"} = \&Dumper;
 }
 
-sub Dumper
-{
+sub Dumper {
     require Data::Dumper;
-    local $Data::Dumper::Indent = 1;
+    local $Data::Dumper::Indent   = 1;
     local $Data::Dumper::Sortkeys = 1;
     Data::Dumper::Dumper(@_);
 }
@@ -46,7 +44,7 @@ Devel::Cover::Dumper - Internal module for debugging purposes
 
 =head1 VERSION
 
-version 1.08
+version 1.33
 
 =head1 SYNOPSIS
 
